// pages/serverConfig/serverConfig.js
const util = require("../../utils/util");
const {
  ab2hex
} = util;

const plugin = requirePlugin("sdkPlugin").AiLink;

Page({

  /**
   * 页面的初始数据
   */
  data: {
    serverAddress: '',
    serverPort: '',
    serverPath: '',
    pwdModal: false,
    itemIndex: 0,
    serverAddressInput: '',
    serverPortInput: '',
    serverPathInput: '',
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {

    wx.onBLECharacteristicValueChange((characteristic) => {
      // 解析特征值，返回解密后的数据
      let bleData = plugin.parseBleData(characteristic.value)
      // console.log(bleData)

      this.dealBleData(bleData)
    })
  

    this.getServerAddress()
    this.getServerPort()
    this.getServerPath()
  },

  showModal() {
    this.setData({
      pwdModal: true
    })
  },

  closeModal() {
    this.setData({
      pwdModal: false
    })
  },
  tapItem(e) {
    let index = e.currentTarget.dataset.index
    console.log('tapItem()', index)
    if (index <= 2) {
      this.setData({
        itemIndex: index
      })
      this.showModal()
    } else {
      //重启模块,模块重启时,ble会断开连接
      console.log('重启模块')
      this.resetBLEModule()
    }
  },

  confirm() {
    console.log('confirm()')
    if (this.data.itemIndex === 0) {
      this.setServerAddress()
    } else if (this.data.itemIndex === 1) {
      this.setServerPort()
    } else if (this.data.itemIndex === 2) {
      this.setServerPath()
    } 
    this.closeModal()
  },

  /**
   * 处理数据
   */
  dealBleData(bleData) {
    if (bleData.status == 0) {
      console.log("握手成功")
    } else if (bleData.status == 1) {
      console.log('A7-----^')
    } else if (bleData.status == 2) {
      console.log(bleData)
      console.log('A6-----^')
      let payload = bleData.data
      const result = ['成功', '失败', '不支持']
      switch (payload[0]) {
        case 0x8B: {
          wx.hideLoading()
          wx.showToast({
            title: '设置服务器地址' + result[payload[1]],
            icon: 'none'
          })
          console.log('设置服务器地址' + result[payload[1]])
          break;
        }
        case 0x8C: {
          console.log('上报服务器地址')
          let end = payload[1]
          if (end === 0) wx.hideLoading()
          let nameArr = payload.slice(2)
          console.log('原始数据===>' + ab2hex(nameArr, ' '))
          let nameStr = nameArr.length ? util.hex2str(nameArr) : ''
          console.log('nameStr: ' + nameStr)
          nameStr = this.data.serverAddress + nameStr
          this.setData({
            serverAddress: nameStr
          })
          break
        }
        case 0x8D: {
          wx.hideLoading()
          wx.showToast({
            title: '设置服务器端口' + result[payload[1]],
            icon: 'none'
          })
          console.log('设置服务器端口' + result[payload[1]])
          break;
        }
        case 0x8E: {
          console.log('上报服务器端口')
          wx.hideLoading()
          let port = payload[1]<<8 | payload[2]
          console.log('port: ' + port)
          this.setData({
            serverPort: port
          })
          break
        }
        case 0x96: {
          wx.hideLoading()
          wx.showToast({
            title: '设置服务器路径' + result[payload[1]],
            icon: 'none'
          })
          console.log('设置服务器路径' + result[payload[1]])
          break;
        }
        case 0x97: {
          console.log('上报服务器路径')
          let end = payload[1]
          if (end === 0) wx.hideLoading()
          let nameArr = payload.slice(2)
          console.log('原始数据===>' + ab2hex(nameArr, ' '))
          let nameStr = nameArr.length ? util.hex2str(nameArr) : ''
          console.log('nameStr: ' + nameStr)
          nameStr = this.data.serverPath + nameStr
          this.setData({
            serverPath: nameStr
          })
          break
        }
      }
    }
  },

  /**
   * 设置服务器地址
   */
  setServerAddress() {
    let str = this.data.serverAddressInput
    if (!str || str.length === 0) {
      wx.showToast({
        title: '请输入服务器地址',
        icon: 'none'
      })
      return
    }
    if (str.length > 56) {
      wx.showToast({
        title: '最多56个字节',
        icon: 'none'
      })
      return
    }
    let arr = util.str2hex(str)
    if (arr.length > 14) { // 超出14 byte 需分包
      console.log('超出14位===')
      let list = []
      let len = parseInt(arr.length / 14) + 1
      for (let i = 0; i < len; i++) {
        setTimeout(() => {
          list[i] = arr.slice(i * 14, (i + 1) * 14)
          console.log('list:', list)
          let isEnd = +(i !== len - 1)
          console.log('isEnd:', isEnd)
          let cmd = [0x8B, isEnd, ...list[i]]
          console.log('cmd:', cmd)
          plugin.sendDataOfA6(cmd)
        }, 200 * i)
      }
      console.log('arr:', arr)
    } else {
      let cmd = [0x8B, 0x00, ...arr]
      plugin.sendDataOfA6(cmd)
    }

    //重新获取ServerAddress用于验证
    setTimeout(() => {
      this.getServerAddress()
    }, 1000)
  },
  /**
   * 设置服务器端口
   */
  setServerPort() {
    let str = this.data.serverPortInput
    let port = parseInt(str)
    console.log('port:', port)
    if (port > 0xFFFF) {
      wx.showToast({
        title: '超过端口号最大值65535',
        icon: 'none'
      })
      return
    }
    let cmd = [0x8D, (port>>8)&0xFF, port&0xFF]
    plugin.sendDataOfA6(cmd)

    //重新获取ServerPort用于验证
    setTimeout(() => {
      this.getServerPort()
    }, 1000)
  },

  /**
   * 设置服务器路径
   */
  setServerPath() {
    let str = this.data.serverPathInput
    if (!str || str.length === 0) {
      wx.showToast({
        title: '请输入服务器路径',
        icon: 'none'
      })
      return
    }
    if (str.length > 56) {
      wx.showToast({
        title: '最多56个字节',
        icon: 'none'
      })
      return
    }
    let arr = util.str2hex(str)
    if (arr.length > 14) { // 超出14 byte 需分包
      console.log('超出14位===')
      let list = []
      let len = parseInt(arr.length / 14) + 1
      for (let i = 0; i < len; i++) {
        setTimeout(() => {
          list[i] = arr.slice(i * 14, (i + 1) * 14)
          console.log('list:', list)
          let isEnd = +(i !== len - 1)
          console.log('isEnd:', isEnd)
          let cmd = [0x96, isEnd, ...list[i]]
          console.log('cmd:', cmd)
          plugin.sendDataOfA6(cmd)
        }, 200 * i)
      }
      console.log('arr:', arr)
    } else {
      let cmd = [0x96, 0x00, ...arr]
      plugin.sendDataOfA6(cmd)
    }

    //重新获取ServerPath用于验证
    setTimeout(() => {
      this.getServerPath()
    }, 1000)
  },

  /**
   * 获取服务器地址
   */
  getServerAddress() {
    this.setData({
      serverAddress: ''
    })
    let cmd = [0x8C]
    plugin.sendDataOfA6(cmd)
  },

  /**
   * 获取服务器端口
   */
  getServerPort() {
    this.setData({
      serverPort: ''
    })
    let cmd = [0x8E]
    plugin.sendDataOfA6(cmd)
  },

  /**
   * 获取服务器路径
   */
  getServerPath() {
    this.setData({
      serverPath: ''
    })
    let cmd = [0x97]
    plugin.sendDataOfA6(cmd)
  },

  /**
   * 重启蓝牙模块
   */
  resetBLEModule() {
    let cmd = [0x21, 0x01]
    plugin.sendDataOfA6(cmd)
  },

})